# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['LoadBalancerArgs', 'LoadBalancer']

@pulumi.input_type
class LoadBalancerArgs:
    def __init__(__self__, *,
                 nics: pulumi.Input[Sequence[pulumi.Input['LoadBalancerNicArgs']]],
                 project_id: pulumi.Input[str],
                 routes: pulumi.Input[Sequence[pulumi.Input['LoadBalancerRouteArgs']]],
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 internet_facing: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTagArgs']]]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTargetArgs']]]] = None):
        """
        The set of arguments for constructing a LoadBalancer resource.
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerNicArgs']]] nics: A set of network interface specifications for this load balancer.
        :param pulumi.Input[str] project_id: The id of the project the current user belongs to.
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerRouteArgs']]] routes: The load balancer route configuration regarding ports and protocols.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional custom properties that may be used to extend the machine.
        :param pulumi.Input[str] deployment_id: The id of the deployment that is associated with this resource.
        :param pulumi.Input[str] description: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param pulumi.Input[bool] internet_facing: An Internet-facing load balancer has a publicly resolvable DNS name, so it can route requests from clients over the Internet to the instances that are registered with the load balancer.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerTagArgs']]] tags: A set of tag keys and optional values that were set on this resource instance.
               example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerTargetArgs']]] targets: A list of links to target load balancer pool members. Links can be to either a machine or a machine's network interface.
        """
        pulumi.set(__self__, "nics", nics)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "routes", routes)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if deployment_id is not None:
            pulumi.set(__self__, "deployment_id", deployment_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if internet_facing is not None:
            pulumi.set(__self__, "internet_facing", internet_facing)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if targets is not None:
            pulumi.set(__self__, "targets", targets)

    @property
    @pulumi.getter
    def nics(self) -> pulumi.Input[Sequence[pulumi.Input['LoadBalancerNicArgs']]]:
        """
        A set of network interface specifications for this load balancer.
        """
        return pulumi.get(self, "nics")

    @nics.setter
    def nics(self, value: pulumi.Input[Sequence[pulumi.Input['LoadBalancerNicArgs']]]):
        pulumi.set(self, "nics", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        """
        The id of the project the current user belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def routes(self) -> pulumi.Input[Sequence[pulumi.Input['LoadBalancerRouteArgs']]]:
        """
        The load balancer route configuration regarding ports and protocols.
        """
        return pulumi.get(self, "routes")

    @routes.setter
    def routes(self, value: pulumi.Input[Sequence[pulumi.Input['LoadBalancerRouteArgs']]]):
        pulumi.set(self, "routes", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Additional custom properties that may be used to extend the machine.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the deployment that is associated with this resource.
        """
        return pulumi.get(self, "deployment_id")

    @deployment_id.setter
    def deployment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deployment_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="internetFacing")
    def internet_facing(self) -> Optional[pulumi.Input[bool]]:
        """
        An Internet-facing load balancer has a publicly resolvable DNS name, so it can route requests from clients over the Internet to the instances that are registered with the load balancer.
        """
        return pulumi.get(self, "internet_facing")

    @internet_facing.setter
    def internet_facing(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "internet_facing", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTagArgs']]]]:
        """
        A set of tag keys and optional values that were set on this resource instance.
        example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTargetArgs']]]]:
        """
        A list of links to target load balancer pool members. Links can be to either a machine or a machine's network interface.
        """
        return pulumi.get(self, "targets")

    @targets.setter
    def targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTargetArgs']]]]):
        pulumi.set(self, "targets", value)


@pulumi.input_type
class _LoadBalancerState:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 external_region_id: Optional[pulumi.Input[str]] = None,
                 external_zone_id: Optional[pulumi.Input[str]] = None,
                 internet_facing: Optional[pulumi.Input[bool]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 nics: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerNicArgs']]]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 routes: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerRouteArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTagArgs']]]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTargetArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering LoadBalancer resources.
        :param pulumi.Input[str] address: Primary address allocated or in use by this load balancer. The address could be an in the form of a publicly resolvable DNS name or an IP address.
        :param pulumi.Input[str] created_at: Date when the entity was created. The date is in ISO 6801 and UTC.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional custom properties that may be used to extend the machine.
        :param pulumi.Input[str] deployment_id: The id of the deployment that is associated with this resource.
        :param pulumi.Input[str] description: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param pulumi.Input[str] external_id: External entity Id on the provider side.
        :param pulumi.Input[str] external_region_id: The external regionId of the resource.
        :param pulumi.Input[str] external_zone_id: The external regionId of the resource.
        :param pulumi.Input[bool] internet_facing: An Internet-facing load balancer has a publicly resolvable DNS name, so it can route requests from clients over the Internet to the instances that are registered with the load balancer.
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerLinkArgs']]] links: HATEOAS of the entity.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerNicArgs']]] nics: A set of network interface specifications for this load balancer.
        :param pulumi.Input[str] organization_id: The id of the organization this entity belongs to.
        :param pulumi.Input[str] owner: Email of the user that owns the entity.
        :param pulumi.Input[str] project_id: The id of the project the current user belongs to.
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerRouteArgs']]] routes: The load balancer route configuration regarding ports and protocols.
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerTagArgs']]] tags: A set of tag keys and optional values that were set on this resource instance.
               example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerTargetArgs']]] targets: A list of links to target load balancer pool members. Links can be to either a machine or a machine's network interface.
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if deployment_id is not None:
            pulumi.set(__self__, "deployment_id", deployment_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if external_region_id is not None:
            pulumi.set(__self__, "external_region_id", external_region_id)
        if external_zone_id is not None:
            pulumi.set(__self__, "external_zone_id", external_zone_id)
        if internet_facing is not None:
            pulumi.set(__self__, "internet_facing", internet_facing)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if nics is not None:
            pulumi.set(__self__, "nics", nics)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if routes is not None:
            pulumi.set(__self__, "routes", routes)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if targets is not None:
            pulumi.set(__self__, "targets", targets)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[str]]:
        """
        Primary address allocated or in use by this load balancer. The address could be an in the form of a publicly resolvable DNS name or an IP address.
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Additional custom properties that may be used to extend the machine.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the deployment that is associated with this resource.
        """
        return pulumi.get(self, "deployment_id")

    @deployment_id.setter
    def deployment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deployment_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The external regionId of the resource.
        """
        return pulumi.get(self, "external_region_id")

    @external_region_id.setter
    def external_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_region_id", value)

    @property
    @pulumi.getter(name="externalZoneId")
    def external_zone_id(self) -> Optional[pulumi.Input[str]]:
        """
        The external regionId of the resource.
        """
        return pulumi.get(self, "external_zone_id")

    @external_zone_id.setter
    def external_zone_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_zone_id", value)

    @property
    @pulumi.getter(name="internetFacing")
    def internet_facing(self) -> Optional[pulumi.Input[bool]]:
        """
        An Internet-facing load balancer has a publicly resolvable DNS name, so it can route requests from clients over the Internet to the instances that are registered with the load balancer.
        """
        return pulumi.get(self, "internet_facing")

    @internet_facing.setter
    def internet_facing(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "internet_facing", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerLinkArgs']]]]:
        """
        HATEOAS of the entity.
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def nics(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerNicArgs']]]]:
        """
        A set of network interface specifications for this load balancer.
        """
        return pulumi.get(self, "nics")

    @nics.setter
    def nics(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerNicArgs']]]]):
        pulumi.set(self, "nics", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the project the current user belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def routes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerRouteArgs']]]]:
        """
        The load balancer route configuration regarding ports and protocols.
        """
        return pulumi.get(self, "routes")

    @routes.setter
    def routes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerRouteArgs']]]]):
        pulumi.set(self, "routes", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTagArgs']]]]:
        """
        A set of tag keys and optional values that were set on this resource instance.
        example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTargetArgs']]]]:
        """
        A list of links to target load balancer pool members. Links can be to either a machine or a machine's network interface.
        """
        return pulumi.get(self, "targets")

    @targets.setter
    def targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTargetArgs']]]]):
        pulumi.set(self, "targets", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class LoadBalancer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 internet_facing: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 nics: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerNicArgs']]]]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 routes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerRouteArgs']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerTagArgs']]]]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerTargetArgs']]]]] = None,
                 __props__=None):
        """
        Creates a VMware vRealize Automation load balancer resource.

        ## Example Usage
        ### S

        The following example shows how to create a load balancer resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.loadbalancer.LoadBalancer("this",
            project_id=vra_project["my-project"]["id"],
            description="My Load Balancer",
            custom_properties={
                "edgeClusterRouterStateLink": "/resources/routers/<uuid>",
                "tier0LogicalRouterStateLink": "/resources/routers/<uuid>",
            },
            targets=[vra.loadbalancer.LoadBalancerTargetArgs(
                machine_id=vra_machine["my_machine"]["id"],
            )],
            nics=[vra.loadbalancer.LoadBalancerNicArgs(
                network_id=data["vra_network"]["my-network"]["id"],
            )],
            routes=[vra.loadbalancer.LoadBalancerRouteArgs(
                protocol="TCP",
                port="80",
                member_protocol="TCP",
                member_port="80",
                health_check_configurations=[vra.loadbalancer.LoadBalancerRouteHealthCheckConfigurationArgs(
                    protocol="TCP",
                    port="80",
                    interval_seconds=30,
                    timeout_seconds=10,
                    unhealthy_threshold=2,
                    healthy_threshold=10,
                )],
            )])
        ```

        A block device resource supports the following arguments:

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional custom properties that may be used to extend the machine.
        :param pulumi.Input[str] deployment_id: The id of the deployment that is associated with this resource.
        :param pulumi.Input[str] description: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param pulumi.Input[bool] internet_facing: An Internet-facing load balancer has a publicly resolvable DNS name, so it can route requests from clients over the Internet to the instances that are registered with the load balancer.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerNicArgs']]]] nics: A set of network interface specifications for this load balancer.
        :param pulumi.Input[str] project_id: The id of the project the current user belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerRouteArgs']]]] routes: The load balancer route configuration regarding ports and protocols.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerTagArgs']]]] tags: A set of tag keys and optional values that were set on this resource instance.
               example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerTargetArgs']]]] targets: A list of links to target load balancer pool members. Links can be to either a machine or a machine's network interface.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LoadBalancerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a VMware vRealize Automation load balancer resource.

        ## Example Usage
        ### S

        The following example shows how to create a load balancer resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.loadbalancer.LoadBalancer("this",
            project_id=vra_project["my-project"]["id"],
            description="My Load Balancer",
            custom_properties={
                "edgeClusterRouterStateLink": "/resources/routers/<uuid>",
                "tier0LogicalRouterStateLink": "/resources/routers/<uuid>",
            },
            targets=[vra.loadbalancer.LoadBalancerTargetArgs(
                machine_id=vra_machine["my_machine"]["id"],
            )],
            nics=[vra.loadbalancer.LoadBalancerNicArgs(
                network_id=data["vra_network"]["my-network"]["id"],
            )],
            routes=[vra.loadbalancer.LoadBalancerRouteArgs(
                protocol="TCP",
                port="80",
                member_protocol="TCP",
                member_port="80",
                health_check_configurations=[vra.loadbalancer.LoadBalancerRouteHealthCheckConfigurationArgs(
                    protocol="TCP",
                    port="80",
                    interval_seconds=30,
                    timeout_seconds=10,
                    unhealthy_threshold=2,
                    healthy_threshold=10,
                )],
            )])
        ```

        A block device resource supports the following arguments:

        :param str resource_name: The name of the resource.
        :param LoadBalancerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LoadBalancerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 internet_facing: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 nics: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerNicArgs']]]]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 routes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerRouteArgs']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerTagArgs']]]]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerTargetArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LoadBalancerArgs.__new__(LoadBalancerArgs)

            __props__.__dict__["custom_properties"] = custom_properties
            __props__.__dict__["deployment_id"] = deployment_id
            __props__.__dict__["description"] = description
            __props__.__dict__["internet_facing"] = internet_facing
            __props__.__dict__["name"] = name
            if nics is None and not opts.urn:
                raise TypeError("Missing required property 'nics'")
            __props__.__dict__["nics"] = nics
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            if routes is None and not opts.urn:
                raise TypeError("Missing required property 'routes'")
            __props__.__dict__["routes"] = routes
            __props__.__dict__["tags"] = tags
            __props__.__dict__["targets"] = targets
            __props__.__dict__["address"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["external_id"] = None
            __props__.__dict__["external_region_id"] = None
            __props__.__dict__["external_zone_id"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["updated_at"] = None
        super(LoadBalancer, __self__).__init__(
            'vra:loadbalancer/loadBalancer:LoadBalancer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            address: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            deployment_id: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            external_id: Optional[pulumi.Input[str]] = None,
            external_region_id: Optional[pulumi.Input[str]] = None,
            external_zone_id: Optional[pulumi.Input[str]] = None,
            internet_facing: Optional[pulumi.Input[bool]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            nics: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerNicArgs']]]]] = None,
            organization_id: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            routes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerRouteArgs']]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerTagArgs']]]]] = None,
            targets: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerTargetArgs']]]]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'LoadBalancer':
        """
        Get an existing LoadBalancer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] address: Primary address allocated or in use by this load balancer. The address could be an in the form of a publicly resolvable DNS name or an IP address.
        :param pulumi.Input[str] created_at: Date when the entity was created. The date is in ISO 6801 and UTC.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional custom properties that may be used to extend the machine.
        :param pulumi.Input[str] deployment_id: The id of the deployment that is associated with this resource.
        :param pulumi.Input[str] description: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param pulumi.Input[str] external_id: External entity Id on the provider side.
        :param pulumi.Input[str] external_region_id: The external regionId of the resource.
        :param pulumi.Input[str] external_zone_id: The external regionId of the resource.
        :param pulumi.Input[bool] internet_facing: An Internet-facing load balancer has a publicly resolvable DNS name, so it can route requests from clients over the Internet to the instances that are registered with the load balancer.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerLinkArgs']]]] links: HATEOAS of the entity.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerNicArgs']]]] nics: A set of network interface specifications for this load balancer.
        :param pulumi.Input[str] organization_id: The id of the organization this entity belongs to.
        :param pulumi.Input[str] owner: Email of the user that owns the entity.
        :param pulumi.Input[str] project_id: The id of the project the current user belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerRouteArgs']]]] routes: The load balancer route configuration regarding ports and protocols.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerTagArgs']]]] tags: A set of tag keys and optional values that were set on this resource instance.
               example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerTargetArgs']]]] targets: A list of links to target load balancer pool members. Links can be to either a machine or a machine's network interface.
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LoadBalancerState.__new__(_LoadBalancerState)

        __props__.__dict__["address"] = address
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["custom_properties"] = custom_properties
        __props__.__dict__["deployment_id"] = deployment_id
        __props__.__dict__["description"] = description
        __props__.__dict__["external_id"] = external_id
        __props__.__dict__["external_region_id"] = external_region_id
        __props__.__dict__["external_zone_id"] = external_zone_id
        __props__.__dict__["internet_facing"] = internet_facing
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["nics"] = nics
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["routes"] = routes
        __props__.__dict__["tags"] = tags
        __props__.__dict__["targets"] = targets
        __props__.__dict__["updated_at"] = updated_at
        return LoadBalancer(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def address(self) -> pulumi.Output[str]:
        """
        Primary address allocated or in use by this load balancer. The address could be an in the form of a publicly resolvable DNS name or an IP address.
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Additional custom properties that may be used to extend the machine.
        """
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> pulumi.Output[str]:
        """
        The id of the deployment that is associated with this resource.
        """
        return pulumi.get(self, "deployment_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> pulumi.Output[str]:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> pulumi.Output[str]:
        """
        The external regionId of the resource.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter(name="externalZoneId")
    def external_zone_id(self) -> pulumi.Output[str]:
        """
        The external regionId of the resource.
        """
        return pulumi.get(self, "external_zone_id")

    @property
    @pulumi.getter(name="internetFacing")
    def internet_facing(self) -> pulumi.Output[Optional[bool]]:
        """
        An Internet-facing load balancer has a publicly resolvable DNS name, so it can route requests from clients over the Internet to the instances that are registered with the load balancer.
        """
        return pulumi.get(self, "internet_facing")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.LoadBalancerLink']]:
        """
        HATEOAS of the entity.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def nics(self) -> pulumi.Output[Sequence['outputs.LoadBalancerNic']]:
        """
        A set of network interface specifications for this load balancer.
        """
        return pulumi.get(self, "nics")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[str]:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        The id of the project the current user belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def routes(self) -> pulumi.Output[Sequence['outputs.LoadBalancerRoute']]:
        """
        The load balancer route configuration regarding ports and protocols.
        """
        return pulumi.get(self, "routes")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.LoadBalancerTag']]:
        """
        A set of tag keys and optional values that were set on this resource instance.
        example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def targets(self) -> pulumi.Output[Optional[Sequence['outputs.LoadBalancerTarget']]]:
        """
        A list of links to target load balancer pool members. Links can be to either a machine or a machine's network interface.
        """
        return pulumi.get(self, "targets")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ContentSourceConfigArgs',
]

@pulumi.input_type
class ContentSourceConfigArgs:
    def __init__(__self__, *,
                 integration_id: pulumi.Input[str],
                 path: pulumi.Input[str],
                 project_name: pulumi.Input[str],
                 branch: Optional[pulumi.Input[str]] = None,
                 content_type: Optional[pulumi.Input[str]] = None,
                 repository: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] integration_id: Content source integration id as seen in vRA integrations.
        :param pulumi.Input[str] path: Path to refer to in the content source repository and branch.
        :param pulumi.Input[str] project_name: Name of the project.
        :param pulumi.Input[str] branch: Content source branch name.
        :param pulumi.Input[str] content_type: Content source type. Supported values are `BLUEPRINT`, `IMAGE`, `ABX_SCRIPTS`, `TERRAFORM_CONFIGURATION`.
        :param pulumi.Input[str] repository: Content source repository.
        """
        pulumi.set(__self__, "integration_id", integration_id)
        pulumi.set(__self__, "path", path)
        pulumi.set(__self__, "project_name", project_name)
        if branch is not None:
            pulumi.set(__self__, "branch", branch)
        if content_type is not None:
            pulumi.set(__self__, "content_type", content_type)
        if repository is not None:
            pulumi.set(__self__, "repository", repository)

    @property
    @pulumi.getter(name="integrationId")
    def integration_id(self) -> pulumi.Input[str]:
        """
        Content source integration id as seen in vRA integrations.
        """
        return pulumi.get(self, "integration_id")

    @integration_id.setter
    def integration_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "integration_id", value)

    @property
    @pulumi.getter
    def path(self) -> pulumi.Input[str]:
        """
        Path to refer to in the content source repository and branch.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: pulumi.Input[str]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Input[str]:
        """
        Name of the project.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def branch(self) -> Optional[pulumi.Input[str]]:
        """
        Content source branch name.
        """
        return pulumi.get(self, "branch")

    @branch.setter
    def branch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "branch", value)

    @property
    @pulumi.getter(name="contentType")
    def content_type(self) -> Optional[pulumi.Input[str]]:
        """
        Content source type. Supported values are `BLUEPRINT`, `IMAGE`, `ABX_SCRIPTS`, `TERRAFORM_CONFIGURATION`.
        """
        return pulumi.get(self, "content_type")

    @content_type.setter
    def content_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content_type", value)

    @property
    @pulumi.getter
    def repository(self) -> Optional[pulumi.Input[str]]:
        """
        Content source repository.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repository", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MachineArgs', 'Machine']

@pulumi.input_type
class MachineArgs:
    def __init__(__self__, *,
                 flavor: pulumi.Input[str],
                 project_id: pulumi.Input[str],
                 boot_config: Optional[pulumi.Input['MachineBootConfigArgs']] = None,
                 constraints: Optional[pulumi.Input[Sequence[pulumi.Input['MachineConstraintArgs']]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disks: Optional[pulumi.Input[Sequence[pulumi.Input['MachineDiskArgs']]]] = None,
                 image: Optional[pulumi.Input[str]] = None,
                 image_disk_constraints: Optional[pulumi.Input[Sequence[pulumi.Input['MachineImageDiskConstraintArgs']]]] = None,
                 image_ref: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 nics: Optional[pulumi.Input[Sequence[pulumi.Input['MachineNicArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['MachineTagArgs']]]] = None):
        """
        The set of arguments for constructing a Machine resource.
        :param pulumi.Input[str] flavor: Flavor of machine instance.
        :param pulumi.Input[str] project_id: ID of project that resource belongs to.
        :param pulumi.Input['MachineBootConfigArgs'] boot_config: Machine boot config that will be passed to the instance. Used to perform common automated configuration tasks and even run scripts after instance starts.
        :param pulumi.Input[Sequence[pulumi.Input['MachineConstraintArgs']]] constraints: Constraints used to drive placement policies for the virtual machine produced from the specification. Constraint expressions are matched against tags on existing placement targets.  
               Example:[{"mandatory" : "true", "expression": "environment":"prod"}, {"mandatory" : "false", "expression": "pci"}]
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional properties that may be used to extend the base type.
        :param pulumi.Input[str] deployment_id: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input['MachineDiskArgs']]] disks: Specification for attaching/detaching disks to a machine.
        :param pulumi.Input[str] image: Type of image used for this machine.
        :param pulumi.Input[Sequence[pulumi.Input['MachineImageDiskConstraintArgs']]] image_disk_constraints: Constraints that are used to drive placement policies for the image disk. Constraint expressions are matched against tags on existing placement targets. example:[{"mandatory" : "true", "expression": "environment:prod"}, {"mandatory" : "false", "expression": "pci"}]. It is nested argument with the following properties.
        :param pulumi.Input[str] image_ref: Direct image reference used for this machine (name, path, location, uri, etc.). Valid if no image property is provided
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[Sequence[pulumi.Input['MachineNicArgs']]] nics: Set of network interface controller specifications for this machine. If not specified, then a default network connection will be created.
        :param pulumi.Input[Sequence[pulumi.Input['MachineTagArgs']]] tags: Set of tag keys and optional values that should be set on any resource that is produced from this specification. example:[ { "key" : "ownedBy", "value": "Rainpole" } ]. It is nested argument with the following properties.
        """
        pulumi.set(__self__, "flavor", flavor)
        pulumi.set(__self__, "project_id", project_id)
        if boot_config is not None:
            pulumi.set(__self__, "boot_config", boot_config)
        if constraints is not None:
            pulumi.set(__self__, "constraints", constraints)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if deployment_id is not None:
            pulumi.set(__self__, "deployment_id", deployment_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disks is not None:
            pulumi.set(__self__, "disks", disks)
        if image is not None:
            pulumi.set(__self__, "image", image)
        if image_disk_constraints is not None:
            pulumi.set(__self__, "image_disk_constraints", image_disk_constraints)
        if image_ref is not None:
            pulumi.set(__self__, "image_ref", image_ref)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if nics is not None:
            pulumi.set(__self__, "nics", nics)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def flavor(self) -> pulumi.Input[str]:
        """
        Flavor of machine instance.
        """
        return pulumi.get(self, "flavor")

    @flavor.setter
    def flavor(self, value: pulumi.Input[str]):
        pulumi.set(self, "flavor", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        """
        ID of project that resource belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="bootConfig")
    def boot_config(self) -> Optional[pulumi.Input['MachineBootConfigArgs']]:
        """
        Machine boot config that will be passed to the instance. Used to perform common automated configuration tasks and even run scripts after instance starts.
        """
        return pulumi.get(self, "boot_config")

    @boot_config.setter
    def boot_config(self, value: Optional[pulumi.Input['MachineBootConfigArgs']]):
        pulumi.set(self, "boot_config", value)

    @property
    @pulumi.getter
    def constraints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MachineConstraintArgs']]]]:
        """
        Constraints used to drive placement policies for the virtual machine produced from the specification. Constraint expressions are matched against tags on existing placement targets.  
        Example:[{"mandatory" : "true", "expression": "environment":"prod"}, {"mandatory" : "false", "expression": "pci"}]
        """
        return pulumi.get(self, "constraints")

    @constraints.setter
    def constraints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MachineConstraintArgs']]]]):
        pulumi.set(self, "constraints", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Additional properties that may be used to extend the base type.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> Optional[pulumi.Input[str]]:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "deployment_id")

    @deployment_id.setter
    def deployment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deployment_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def disks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MachineDiskArgs']]]]:
        """
        Specification for attaching/detaching disks to a machine.
        """
        return pulumi.get(self, "disks")

    @disks.setter
    def disks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MachineDiskArgs']]]]):
        pulumi.set(self, "disks", value)

    @property
    @pulumi.getter
    def image(self) -> Optional[pulumi.Input[str]]:
        """
        Type of image used for this machine.
        """
        return pulumi.get(self, "image")

    @image.setter
    def image(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image", value)

    @property
    @pulumi.getter(name="imageDiskConstraints")
    def image_disk_constraints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MachineImageDiskConstraintArgs']]]]:
        """
        Constraints that are used to drive placement policies for the image disk. Constraint expressions are matched against tags on existing placement targets. example:[{"mandatory" : "true", "expression": "environment:prod"}, {"mandatory" : "false", "expression": "pci"}]. It is nested argument with the following properties.
        """
        return pulumi.get(self, "image_disk_constraints")

    @image_disk_constraints.setter
    def image_disk_constraints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MachineImageDiskConstraintArgs']]]]):
        pulumi.set(self, "image_disk_constraints", value)

    @property
    @pulumi.getter(name="imageRef")
    def image_ref(self) -> Optional[pulumi.Input[str]]:
        """
        Direct image reference used for this machine (name, path, location, uri, etc.). Valid if no image property is provided
        """
        return pulumi.get(self, "image_ref")

    @image_ref.setter
    def image_ref(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_ref", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def nics(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MachineNicArgs']]]]:
        """
        Set of network interface controller specifications for this machine. If not specified, then a default network connection will be created.
        """
        return pulumi.get(self, "nics")

    @nics.setter
    def nics(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MachineNicArgs']]]]):
        pulumi.set(self, "nics", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MachineTagArgs']]]]:
        """
        Set of tag keys and optional values that should be set on any resource that is produced from this specification. example:[ { "key" : "ownedBy", "value": "Rainpole" } ]. It is nested argument with the following properties.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MachineTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _MachineState:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[str]] = None,
                 boot_config: Optional[pulumi.Input['MachineBootConfigArgs']] = None,
                 constraints: Optional[pulumi.Input[Sequence[pulumi.Input['MachineConstraintArgs']]]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disks: Optional[pulumi.Input[Sequence[pulumi.Input['MachineDiskArgs']]]] = None,
                 disks_lists: Optional[pulumi.Input[Sequence[pulumi.Input['MachineDisksListArgs']]]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 external_region_id: Optional[pulumi.Input[str]] = None,
                 external_zone_id: Optional[pulumi.Input[str]] = None,
                 flavor: Optional[pulumi.Input[str]] = None,
                 image: Optional[pulumi.Input[str]] = None,
                 image_disk_constraints: Optional[pulumi.Input[Sequence[pulumi.Input['MachineImageDiskConstraintArgs']]]] = None,
                 image_ref: Optional[pulumi.Input[str]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['MachineLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 nics: Optional[pulumi.Input[Sequence[pulumi.Input['MachineNicArgs']]]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 power_state: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['MachineTagArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Machine resources.
        :param pulumi.Input[str] address: Primary address allocated or in use by this machine. The actual type of the address depends on the adapter type. Typically it is either the public or the external IP address.
        :param pulumi.Input['MachineBootConfigArgs'] boot_config: Machine boot config that will be passed to the instance. Used to perform common automated configuration tasks and even run scripts after instance starts.
        :param pulumi.Input[Sequence[pulumi.Input['MachineConstraintArgs']]] constraints: Constraints used to drive placement policies for the virtual machine produced from the specification. Constraint expressions are matched against tags on existing placement targets.  
               Example:[{"mandatory" : "true", "expression": "environment":"prod"}, {"mandatory" : "false", "expression": "pci"}]
        :param pulumi.Input[str] created_at: Date when the entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional properties that may be used to extend the base type.
        :param pulumi.Input[str] deployment_id: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input['MachineDiskArgs']]] disks: Specification for attaching/detaching disks to a machine.
        :param pulumi.Input[Sequence[pulumi.Input['MachineDisksListArgs']]] disks_lists: List of all disks attached to a machine including boot disk, and additional block devices attached using the disks attribute.
        :param pulumi.Input[str] external_id: External entity ID on the provider side.
        :param pulumi.Input[str] external_region_id: External regionId of the resource.
        :param pulumi.Input[str] external_zone_id: External zoneId of the resource.
        :param pulumi.Input[str] flavor: Flavor of machine instance.
        :param pulumi.Input[str] image: Type of image used for this machine.
        :param pulumi.Input[Sequence[pulumi.Input['MachineImageDiskConstraintArgs']]] image_disk_constraints: Constraints that are used to drive placement policies for the image disk. Constraint expressions are matched against tags on existing placement targets. example:[{"mandatory" : "true", "expression": "environment:prod"}, {"mandatory" : "false", "expression": "pci"}]. It is nested argument with the following properties.
        :param pulumi.Input[str] image_ref: Direct image reference used for this machine (name, path, location, uri, etc.). Valid if no image property is provided
        :param pulumi.Input[Sequence[pulumi.Input['MachineLinkArgs']]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[Sequence[pulumi.Input['MachineNicArgs']]] nics: Set of network interface controller specifications for this machine. If not specified, then a default network connection will be created.
        :param pulumi.Input[str] organization_id: ID of the organization this entity belongs to.
        :param pulumi.Input[str] owner: Email of entity owner.
        :param pulumi.Input[str] power_state: Power state of machine.
        :param pulumi.Input[str] project_id: ID of project that resource belongs to.
        :param pulumi.Input[Sequence[pulumi.Input['MachineTagArgs']]] tags: Set of tag keys and optional values that should be set on any resource that is produced from this specification. example:[ { "key" : "ownedBy", "value": "Rainpole" } ]. It is nested argument with the following properties.
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if boot_config is not None:
            pulumi.set(__self__, "boot_config", boot_config)
        if constraints is not None:
            pulumi.set(__self__, "constraints", constraints)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if deployment_id is not None:
            pulumi.set(__self__, "deployment_id", deployment_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disks is not None:
            pulumi.set(__self__, "disks", disks)
        if disks_lists is not None:
            pulumi.set(__self__, "disks_lists", disks_lists)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if external_region_id is not None:
            pulumi.set(__self__, "external_region_id", external_region_id)
        if external_zone_id is not None:
            pulumi.set(__self__, "external_zone_id", external_zone_id)
        if flavor is not None:
            pulumi.set(__self__, "flavor", flavor)
        if image is not None:
            pulumi.set(__self__, "image", image)
        if image_disk_constraints is not None:
            pulumi.set(__self__, "image_disk_constraints", image_disk_constraints)
        if image_ref is not None:
            pulumi.set(__self__, "image_ref", image_ref)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if nics is not None:
            pulumi.set(__self__, "nics", nics)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if power_state is not None:
            pulumi.set(__self__, "power_state", power_state)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[str]]:
        """
        Primary address allocated or in use by this machine. The actual type of the address depends on the adapter type. Typically it is either the public or the external IP address.
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter(name="bootConfig")
    def boot_config(self) -> Optional[pulumi.Input['MachineBootConfigArgs']]:
        """
        Machine boot config that will be passed to the instance. Used to perform common automated configuration tasks and even run scripts after instance starts.
        """
        return pulumi.get(self, "boot_config")

    @boot_config.setter
    def boot_config(self, value: Optional[pulumi.Input['MachineBootConfigArgs']]):
        pulumi.set(self, "boot_config", value)

    @property
    @pulumi.getter
    def constraints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MachineConstraintArgs']]]]:
        """
        Constraints used to drive placement policies for the virtual machine produced from the specification. Constraint expressions are matched against tags on existing placement targets.  
        Example:[{"mandatory" : "true", "expression": "environment":"prod"}, {"mandatory" : "false", "expression": "pci"}]
        """
        return pulumi.get(self, "constraints")

    @constraints.setter
    def constraints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MachineConstraintArgs']]]]):
        pulumi.set(self, "constraints", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Additional properties that may be used to extend the base type.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> Optional[pulumi.Input[str]]:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "deployment_id")

    @deployment_id.setter
    def deployment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deployment_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def disks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MachineDiskArgs']]]]:
        """
        Specification for attaching/detaching disks to a machine.
        """
        return pulumi.get(self, "disks")

    @disks.setter
    def disks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MachineDiskArgs']]]]):
        pulumi.set(self, "disks", value)

    @property
    @pulumi.getter(name="disksLists")
    def disks_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MachineDisksListArgs']]]]:
        """
        List of all disks attached to a machine including boot disk, and additional block devices attached using the disks attribute.
        """
        return pulumi.get(self, "disks_lists")

    @disks_lists.setter
    def disks_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MachineDisksListArgs']]]]):
        pulumi.set(self, "disks_lists", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        """
        External entity ID on the provider side.
        """
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        External regionId of the resource.
        """
        return pulumi.get(self, "external_region_id")

    @external_region_id.setter
    def external_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_region_id", value)

    @property
    @pulumi.getter(name="externalZoneId")
    def external_zone_id(self) -> Optional[pulumi.Input[str]]:
        """
        External zoneId of the resource.
        """
        return pulumi.get(self, "external_zone_id")

    @external_zone_id.setter
    def external_zone_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_zone_id", value)

    @property
    @pulumi.getter
    def flavor(self) -> Optional[pulumi.Input[str]]:
        """
        Flavor of machine instance.
        """
        return pulumi.get(self, "flavor")

    @flavor.setter
    def flavor(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "flavor", value)

    @property
    @pulumi.getter
    def image(self) -> Optional[pulumi.Input[str]]:
        """
        Type of image used for this machine.
        """
        return pulumi.get(self, "image")

    @image.setter
    def image(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image", value)

    @property
    @pulumi.getter(name="imageDiskConstraints")
    def image_disk_constraints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MachineImageDiskConstraintArgs']]]]:
        """
        Constraints that are used to drive placement policies for the image disk. Constraint expressions are matched against tags on existing placement targets. example:[{"mandatory" : "true", "expression": "environment:prod"}, {"mandatory" : "false", "expression": "pci"}]. It is nested argument with the following properties.
        """
        return pulumi.get(self, "image_disk_constraints")

    @image_disk_constraints.setter
    def image_disk_constraints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MachineImageDiskConstraintArgs']]]]):
        pulumi.set(self, "image_disk_constraints", value)

    @property
    @pulumi.getter(name="imageRef")
    def image_ref(self) -> Optional[pulumi.Input[str]]:
        """
        Direct image reference used for this machine (name, path, location, uri, etc.). Valid if no image property is provided
        """
        return pulumi.get(self, "image_ref")

    @image_ref.setter
    def image_ref(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_ref", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MachineLinkArgs']]]]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MachineLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def nics(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MachineNicArgs']]]]:
        """
        Set of network interface controller specifications for this machine. If not specified, then a default network connection will be created.
        """
        return pulumi.get(self, "nics")

    @nics.setter
    def nics(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MachineNicArgs']]]]):
        pulumi.set(self, "nics", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the organization this entity belongs to.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Email of entity owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="powerState")
    def power_state(self) -> Optional[pulumi.Input[str]]:
        """
        Power state of machine.
        """
        return pulumi.get(self, "power_state")

    @power_state.setter
    def power_state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "power_state", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of project that resource belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MachineTagArgs']]]]:
        """
        Set of tag keys and optional values that should be set on any resource that is produced from this specification. example:[ { "key" : "ownedBy", "value": "Rainpole" } ]. It is nested argument with the following properties.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MachineTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class Machine(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 boot_config: Optional[pulumi.Input[pulumi.InputType['MachineBootConfigArgs']]] = None,
                 constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineConstraintArgs']]]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disks: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineDiskArgs']]]]] = None,
                 flavor: Optional[pulumi.Input[str]] = None,
                 image: Optional[pulumi.Input[str]] = None,
                 image_disk_constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineImageDiskConstraintArgs']]]]] = None,
                 image_ref: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 nics: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineNicArgs']]]]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineTagArgs']]]]] = None,
                 __props__=None):
        """
        Creates a VMware vRealize Automation machine resource.

        ## Example Usage
        ### S

        The following example shows how to create a machine resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.machine.Machine("this",
            description="terrafrom test machine",
            project_id=data["vra_project"]["this"]["id"],
            image="ubuntu2",
            flavor="medium",
            boot_config=vra.machine.MachineBootConfigArgs(
                content=\"\"\"#cloud-config
          users:
          - default
          - name: myuser
            sudo: ['ALL=(ALL) NOPASSWD:ALL']
            groups: [wheel, sudo, admin]
            shell: '/bin/bash'
            ssh-authorized-keys: |
              ssh-rsa your-ssh-rsa:
            - sudo sed -e 's/.*PasswordAuthentication yes.*/PasswordAuthentication no/' -i /etc/ssh/sshd_config
            - sudo service sshd restart
        \"\"\",
            ),
            nics=[vra.machine.MachineNicArgs(
                network_id=data["vra_network"]["this"]["id"],
            )],
            constraints=[vra.machine.MachineConstraintArgs(
                mandatory=True,
                expression="AWS",
            )],
            tags=[vra.machine.MachineTagArgs(
                key="foo",
                value="bar",
            )],
            disks=[
                vra.machine.MachineDiskArgs(
                    block_device_id=vra_block_device["disk1"]["id"],
                ),
                vra.machine.MachineDiskArgs(
                    block_device_id=vra_block_device["disk2"]["id"],
                ),
            ])
        ```
        A machine resource supports the following resource:

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['MachineBootConfigArgs']] boot_config: Machine boot config that will be passed to the instance. Used to perform common automated configuration tasks and even run scripts after instance starts.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineConstraintArgs']]]] constraints: Constraints used to drive placement policies for the virtual machine produced from the specification. Constraint expressions are matched against tags on existing placement targets.  
               Example:[{"mandatory" : "true", "expression": "environment":"prod"}, {"mandatory" : "false", "expression": "pci"}]
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional properties that may be used to extend the base type.
        :param pulumi.Input[str] deployment_id: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineDiskArgs']]]] disks: Specification for attaching/detaching disks to a machine.
        :param pulumi.Input[str] flavor: Flavor of machine instance.
        :param pulumi.Input[str] image: Type of image used for this machine.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineImageDiskConstraintArgs']]]] image_disk_constraints: Constraints that are used to drive placement policies for the image disk. Constraint expressions are matched against tags on existing placement targets. example:[{"mandatory" : "true", "expression": "environment:prod"}, {"mandatory" : "false", "expression": "pci"}]. It is nested argument with the following properties.
        :param pulumi.Input[str] image_ref: Direct image reference used for this machine (name, path, location, uri, etc.). Valid if no image property is provided
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineNicArgs']]]] nics: Set of network interface controller specifications for this machine. If not specified, then a default network connection will be created.
        :param pulumi.Input[str] project_id: ID of project that resource belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineTagArgs']]]] tags: Set of tag keys and optional values that should be set on any resource that is produced from this specification. example:[ { "key" : "ownedBy", "value": "Rainpole" } ]. It is nested argument with the following properties.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MachineArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a VMware vRealize Automation machine resource.

        ## Example Usage
        ### S

        The following example shows how to create a machine resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.machine.Machine("this",
            description="terrafrom test machine",
            project_id=data["vra_project"]["this"]["id"],
            image="ubuntu2",
            flavor="medium",
            boot_config=vra.machine.MachineBootConfigArgs(
                content=\"\"\"#cloud-config
          users:
          - default
          - name: myuser
            sudo: ['ALL=(ALL) NOPASSWD:ALL']
            groups: [wheel, sudo, admin]
            shell: '/bin/bash'
            ssh-authorized-keys: |
              ssh-rsa your-ssh-rsa:
            - sudo sed -e 's/.*PasswordAuthentication yes.*/PasswordAuthentication no/' -i /etc/ssh/sshd_config
            - sudo service sshd restart
        \"\"\",
            ),
            nics=[vra.machine.MachineNicArgs(
                network_id=data["vra_network"]["this"]["id"],
            )],
            constraints=[vra.machine.MachineConstraintArgs(
                mandatory=True,
                expression="AWS",
            )],
            tags=[vra.machine.MachineTagArgs(
                key="foo",
                value="bar",
            )],
            disks=[
                vra.machine.MachineDiskArgs(
                    block_device_id=vra_block_device["disk1"]["id"],
                ),
                vra.machine.MachineDiskArgs(
                    block_device_id=vra_block_device["disk2"]["id"],
                ),
            ])
        ```
        A machine resource supports the following resource:

        :param str resource_name: The name of the resource.
        :param MachineArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MachineArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 boot_config: Optional[pulumi.Input[pulumi.InputType['MachineBootConfigArgs']]] = None,
                 constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineConstraintArgs']]]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disks: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineDiskArgs']]]]] = None,
                 flavor: Optional[pulumi.Input[str]] = None,
                 image: Optional[pulumi.Input[str]] = None,
                 image_disk_constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineImageDiskConstraintArgs']]]]] = None,
                 image_ref: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 nics: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineNicArgs']]]]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineTagArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MachineArgs.__new__(MachineArgs)

            __props__.__dict__["boot_config"] = boot_config
            __props__.__dict__["constraints"] = constraints
            __props__.__dict__["custom_properties"] = custom_properties
            __props__.__dict__["deployment_id"] = deployment_id
            __props__.__dict__["description"] = description
            __props__.__dict__["disks"] = disks
            if flavor is None and not opts.urn:
                raise TypeError("Missing required property 'flavor'")
            __props__.__dict__["flavor"] = flavor
            __props__.__dict__["image"] = image
            __props__.__dict__["image_disk_constraints"] = image_disk_constraints
            __props__.__dict__["image_ref"] = image_ref
            __props__.__dict__["name"] = name
            __props__.__dict__["nics"] = nics
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["address"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["disks_lists"] = None
            __props__.__dict__["external_id"] = None
            __props__.__dict__["external_region_id"] = None
            __props__.__dict__["external_zone_id"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["power_state"] = None
            __props__.__dict__["updated_at"] = None
        super(Machine, __self__).__init__(
            'vra:machine/machine:Machine',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            address: Optional[pulumi.Input[str]] = None,
            boot_config: Optional[pulumi.Input[pulumi.InputType['MachineBootConfigArgs']]] = None,
            constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineConstraintArgs']]]]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            deployment_id: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            disks: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineDiskArgs']]]]] = None,
            disks_lists: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineDisksListArgs']]]]] = None,
            external_id: Optional[pulumi.Input[str]] = None,
            external_region_id: Optional[pulumi.Input[str]] = None,
            external_zone_id: Optional[pulumi.Input[str]] = None,
            flavor: Optional[pulumi.Input[str]] = None,
            image: Optional[pulumi.Input[str]] = None,
            image_disk_constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineImageDiskConstraintArgs']]]]] = None,
            image_ref: Optional[pulumi.Input[str]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            nics: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineNicArgs']]]]] = None,
            organization_id: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            power_state: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineTagArgs']]]]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'Machine':
        """
        Get an existing Machine resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] address: Primary address allocated or in use by this machine. The actual type of the address depends on the adapter type. Typically it is either the public or the external IP address.
        :param pulumi.Input[pulumi.InputType['MachineBootConfigArgs']] boot_config: Machine boot config that will be passed to the instance. Used to perform common automated configuration tasks and even run scripts after instance starts.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineConstraintArgs']]]] constraints: Constraints used to drive placement policies for the virtual machine produced from the specification. Constraint expressions are matched against tags on existing placement targets.  
               Example:[{"mandatory" : "true", "expression": "environment":"prod"}, {"mandatory" : "false", "expression": "pci"}]
        :param pulumi.Input[str] created_at: Date when the entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional properties that may be used to extend the base type.
        :param pulumi.Input[str] deployment_id: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineDiskArgs']]]] disks: Specification for attaching/detaching disks to a machine.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineDisksListArgs']]]] disks_lists: List of all disks attached to a machine including boot disk, and additional block devices attached using the disks attribute.
        :param pulumi.Input[str] external_id: External entity ID on the provider side.
        :param pulumi.Input[str] external_region_id: External regionId of the resource.
        :param pulumi.Input[str] external_zone_id: External zoneId of the resource.
        :param pulumi.Input[str] flavor: Flavor of machine instance.
        :param pulumi.Input[str] image: Type of image used for this machine.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineImageDiskConstraintArgs']]]] image_disk_constraints: Constraints that are used to drive placement policies for the image disk. Constraint expressions are matched against tags on existing placement targets. example:[{"mandatory" : "true", "expression": "environment:prod"}, {"mandatory" : "false", "expression": "pci"}]. It is nested argument with the following properties.
        :param pulumi.Input[str] image_ref: Direct image reference used for this machine (name, path, location, uri, etc.). Valid if no image property is provided
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineLinkArgs']]]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineNicArgs']]]] nics: Set of network interface controller specifications for this machine. If not specified, then a default network connection will be created.
        :param pulumi.Input[str] organization_id: ID of the organization this entity belongs to.
        :param pulumi.Input[str] owner: Email of entity owner.
        :param pulumi.Input[str] power_state: Power state of machine.
        :param pulumi.Input[str] project_id: ID of project that resource belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MachineTagArgs']]]] tags: Set of tag keys and optional values that should be set on any resource that is produced from this specification. example:[ { "key" : "ownedBy", "value": "Rainpole" } ]. It is nested argument with the following properties.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MachineState.__new__(_MachineState)

        __props__.__dict__["address"] = address
        __props__.__dict__["boot_config"] = boot_config
        __props__.__dict__["constraints"] = constraints
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["custom_properties"] = custom_properties
        __props__.__dict__["deployment_id"] = deployment_id
        __props__.__dict__["description"] = description
        __props__.__dict__["disks"] = disks
        __props__.__dict__["disks_lists"] = disks_lists
        __props__.__dict__["external_id"] = external_id
        __props__.__dict__["external_region_id"] = external_region_id
        __props__.__dict__["external_zone_id"] = external_zone_id
        __props__.__dict__["flavor"] = flavor
        __props__.__dict__["image"] = image
        __props__.__dict__["image_disk_constraints"] = image_disk_constraints
        __props__.__dict__["image_ref"] = image_ref
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["nics"] = nics
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["power_state"] = power_state
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        return Machine(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def address(self) -> pulumi.Output[str]:
        """
        Primary address allocated or in use by this machine. The actual type of the address depends on the adapter type. Typically it is either the public or the external IP address.
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="bootConfig")
    def boot_config(self) -> pulumi.Output[Optional['outputs.MachineBootConfig']]:
        """
        Machine boot config that will be passed to the instance. Used to perform common automated configuration tasks and even run scripts after instance starts.
        """
        return pulumi.get(self, "boot_config")

    @property
    @pulumi.getter
    def constraints(self) -> pulumi.Output[Optional[Sequence['outputs.MachineConstraint']]]:
        """
        Constraints used to drive placement policies for the virtual machine produced from the specification. Constraint expressions are matched against tags on existing placement targets.  
        Example:[{"mandatory" : "true", "expression": "environment":"prod"}, {"mandatory" : "false", "expression": "pci"}]
        """
        return pulumi.get(self, "constraints")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Additional properties that may be used to extend the base type.
        """
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> pulumi.Output[str]:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "deployment_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def disks(self) -> pulumi.Output[Optional[Sequence['outputs.MachineDisk']]]:
        """
        Specification for attaching/detaching disks to a machine.
        """
        return pulumi.get(self, "disks")

    @property
    @pulumi.getter(name="disksLists")
    def disks_lists(self) -> pulumi.Output[Sequence['outputs.MachineDisksList']]:
        """
        List of all disks attached to a machine including boot disk, and additional block devices attached using the disks attribute.
        """
        return pulumi.get(self, "disks_lists")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> pulumi.Output[str]:
        """
        External entity ID on the provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> pulumi.Output[str]:
        """
        External regionId of the resource.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter(name="externalZoneId")
    def external_zone_id(self) -> pulumi.Output[str]:
        """
        External zoneId of the resource.
        """
        return pulumi.get(self, "external_zone_id")

    @property
    @pulumi.getter
    def flavor(self) -> pulumi.Output[str]:
        """
        Flavor of machine instance.
        """
        return pulumi.get(self, "flavor")

    @property
    @pulumi.getter
    def image(self) -> pulumi.Output[Optional[str]]:
        """
        Type of image used for this machine.
        """
        return pulumi.get(self, "image")

    @property
    @pulumi.getter(name="imageDiskConstraints")
    def image_disk_constraints(self) -> pulumi.Output[Optional[Sequence['outputs.MachineImageDiskConstraint']]]:
        """
        Constraints that are used to drive placement policies for the image disk. Constraint expressions are matched against tags on existing placement targets. example:[{"mandatory" : "true", "expression": "environment:prod"}, {"mandatory" : "false", "expression": "pci"}]. It is nested argument with the following properties.
        """
        return pulumi.get(self, "image_disk_constraints")

    @property
    @pulumi.getter(name="imageRef")
    def image_ref(self) -> pulumi.Output[Optional[str]]:
        """
        Direct image reference used for this machine (name, path, location, uri, etc.). Valid if no image property is provided
        """
        return pulumi.get(self, "image_ref")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.MachineLink']]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def nics(self) -> pulumi.Output[Optional[Sequence['outputs.MachineNic']]]:
        """
        Set of network interface controller specifications for this machine. If not specified, then a default network connection will be created.
        """
        return pulumi.get(self, "nics")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[str]:
        """
        ID of the organization this entity belongs to.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Email of entity owner.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="powerState")
    def power_state(self) -> pulumi.Output[str]:
        """
        Power state of machine.
        """
        return pulumi.get(self, "power_state")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        ID of project that resource belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.MachineTag']]:
        """
        Set of tag keys and optional values that should be set on any resource that is produced from this specification. example:[ { "key" : "ownedBy", "value": "Rainpole" } ]. It is nested argument with the following properties.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetItemResult',
    'AwaitableGetItemResult',
    'get_item',
    'get_item_output',
]

@pulumi.output_type
class GetItemResult:
    """
    A collection of values returned by getItem.
    """
    def __init__(__self__, created_at=None, created_by=None, description=None, expand_projects=None, expand_versions=None, id=None, last_updated_at=None, last_updated_by=None, name=None, project_ids=None, projects=None, schema=None, source_id=None, source_name=None, types=None, versions=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if expand_projects and not isinstance(expand_projects, bool):
            raise TypeError("Expected argument 'expand_projects' to be a bool")
        pulumi.set(__self__, "expand_projects", expand_projects)
        if expand_versions and not isinstance(expand_versions, bool):
            raise TypeError("Expected argument 'expand_versions' to be a bool")
        pulumi.set(__self__, "expand_versions", expand_versions)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_updated_at and not isinstance(last_updated_at, str):
            raise TypeError("Expected argument 'last_updated_at' to be a str")
        pulumi.set(__self__, "last_updated_at", last_updated_at)
        if last_updated_by and not isinstance(last_updated_by, str):
            raise TypeError("Expected argument 'last_updated_by' to be a str")
        pulumi.set(__self__, "last_updated_by", last_updated_by)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project_ids and not isinstance(project_ids, list):
            raise TypeError("Expected argument 'project_ids' to be a list")
        pulumi.set(__self__, "project_ids", project_ids)
        if projects and not isinstance(projects, list):
            raise TypeError("Expected argument 'projects' to be a list")
        pulumi.set(__self__, "projects", projects)
        if schema and not isinstance(schema, str):
            raise TypeError("Expected argument 'schema' to be a str")
        pulumi.set(__self__, "schema", schema)
        if source_id and not isinstance(source_id, str):
            raise TypeError("Expected argument 'source_id' to be a str")
        pulumi.set(__self__, "source_id", source_id)
        if source_name and not isinstance(source_name, str):
            raise TypeError("Expected argument 'source_name' to be a str")
        pulumi.set(__self__, "source_name", source_name)
        if types and not isinstance(types, list):
            raise TypeError("Expected argument 'types' to be a list")
        pulumi.set(__self__, "types", types)
        if versions and not isinstance(versions, list):
            raise TypeError("Expected argument 'versions' to be a list")
        pulumi.set(__self__, "versions", versions)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date-time when catalog item version was created at.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> str:
        """
        The user the entity was created by.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="expandProjects")
    def expand_projects(self) -> Optional[bool]:
        return pulumi.get(self, "expand_projects")

    @property
    @pulumi.getter(name="expandVersions")
    def expand_versions(self) -> Optional[bool]:
        return pulumi.get(self, "expand_versions")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Id of the catalog item version.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastUpdatedAt")
    def last_updated_at(self) -> str:
        """
        Date-time when the entity was last updated.
        """
        return pulumi.get(self, "last_updated_at")

    @property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> str:
        """
        The user the entity was last updated by.
        """
        return pulumi.get(self, "last_updated_by")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the entity.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectIds")
    def project_ids(self) -> Sequence[str]:
        """
        List of associated project IDs that can be used for requesting this catalog item.
        """
        return pulumi.get(self, "project_ids")

    @property
    @pulumi.getter
    def projects(self) -> Sequence['outputs.GetItemProjectResult']:
        """
        List of associated projects that can be used for requesting this catalog item.
        """
        return pulumi.get(self, "projects")

    @property
    @pulumi.getter
    def schema(self) -> str:
        """
        Json schema describing request parameters, a simplified version of http://json-schema.org/latest/json-schema-validation.html#rfc.section.5
        """
        return pulumi.get(self, "schema")

    @property
    @pulumi.getter(name="sourceId")
    def source_id(self) -> str:
        """
        LibraryItem source ID.
        """
        return pulumi.get(self, "source_id")

    @property
    @pulumi.getter(name="sourceName")
    def source_name(self) -> str:
        """
        LibraryItem source name.
        """
        return pulumi.get(self, "source_name")

    @property
    @pulumi.getter
    def types(self) -> Sequence['outputs.GetItemTypeResult']:
        return pulumi.get(self, "types")

    @property
    @pulumi.getter
    def versions(self) -> Sequence['outputs.GetItemVersionResult']:
        """
        Catalog item versions.
        """
        return pulumi.get(self, "versions")


class AwaitableGetItemResult(GetItemResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetItemResult(
            created_at=self.created_at,
            created_by=self.created_by,
            description=self.description,
            expand_projects=self.expand_projects,
            expand_versions=self.expand_versions,
            id=self.id,
            last_updated_at=self.last_updated_at,
            last_updated_by=self.last_updated_by,
            name=self.name,
            project_ids=self.project_ids,
            projects=self.projects,
            schema=self.schema,
            source_id=self.source_id,
            source_name=self.source_name,
            types=self.types,
            versions=self.versions)


def get_item(expand_projects: Optional[bool] = None,
             expand_versions: Optional[bool] = None,
             id: Optional[str] = None,
             name: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetItemResult:
    """
    This data source provides information about a catalog item in vRA.

    ## Example Usage
    ### S

    This is an example of how to get a vRA catalog item by its name.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.catalog.get_item(name=var["catalog_item_name"],
        expand_versions=True)
    ```

    This is an example of how to get a vRA catalog item by its id.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.catalog.get_item(id=var["catalog_item_id"],
        expand_versions=True)
    ```


    :param bool expand_projects: Flag to indicate whether to expand detailed project data for the catalog item.
    :param bool expand_versions: Flag to indicate whether to expand detailed versions of the catalog item.
    :param str id: The id of catalog item. One of `id`, or `name` must be provided.
    :param str name: Name of the catalog item. One of `id`, or `name` must be provided.
    """
    __args__ = dict()
    __args__['expandProjects'] = expand_projects
    __args__['expandVersions'] = expand_versions
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:catalog/getItem:getItem', __args__, opts=opts, typ=GetItemResult).value

    return AwaitableGetItemResult(
        created_at=__ret__.created_at,
        created_by=__ret__.created_by,
        description=__ret__.description,
        expand_projects=__ret__.expand_projects,
        expand_versions=__ret__.expand_versions,
        id=__ret__.id,
        last_updated_at=__ret__.last_updated_at,
        last_updated_by=__ret__.last_updated_by,
        name=__ret__.name,
        project_ids=__ret__.project_ids,
        projects=__ret__.projects,
        schema=__ret__.schema,
        source_id=__ret__.source_id,
        source_name=__ret__.source_name,
        types=__ret__.types,
        versions=__ret__.versions)


@_utilities.lift_output_func(get_item)
def get_item_output(expand_projects: Optional[pulumi.Input[Optional[bool]]] = None,
                    expand_versions: Optional[pulumi.Input[Optional[bool]]] = None,
                    id: Optional[pulumi.Input[Optional[str]]] = None,
                    name: Optional[pulumi.Input[Optional[str]]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetItemResult]:
    """
    This data source provides information about a catalog item in vRA.

    ## Example Usage
    ### S

    This is an example of how to get a vRA catalog item by its name.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.catalog.get_item(name=var["catalog_item_name"],
        expand_versions=True)
    ```

    This is an example of how to get a vRA catalog item by its id.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.catalog.get_item(id=var["catalog_item_id"],
        expand_versions=True)
    ```


    :param bool expand_projects: Flag to indicate whether to expand detailed project data for the catalog item.
    :param bool expand_versions: Flag to indicate whether to expand detailed versions of the catalog item.
    :param str id: The id of catalog item. One of `id`, or `name` must be provided.
    :param str name: Name of the catalog item. One of `id`, or `name` must be provided.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetEnumerationAwsResult',
    'AwaitableGetEnumerationAwsResult',
    'get_enumeration_aws',
    'get_enumeration_aws_output',
]

@pulumi.output_type
class GetEnumerationAwsResult:
    """
    A collection of values returned by getEnumerationAws.
    """
    def __init__(__self__, access_key=None, id=None, regions=None, secret_key=None):
        if access_key and not isinstance(access_key, str):
            raise TypeError("Expected argument 'access_key' to be a str")
        pulumi.set(__self__, "access_key", access_key)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)
        if secret_key and not isinstance(secret_key, str):
            raise TypeError("Expected argument 'secret_key' to be a str")
        pulumi.set(__self__, "secret_key", secret_key)

    @property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> str:
        return pulumi.get(self, "access_key")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def regions(self) -> Sequence[str]:
        """
        A set of Region names to enable provisioning on. Example: us-east-2, ap-northeast-1
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> str:
        return pulumi.get(self, "secret_key")


class AwaitableGetEnumerationAwsResult(GetEnumerationAwsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnumerationAwsResult(
            access_key=self.access_key,
            id=self.id,
            regions=self.regions,
            secret_key=self.secret_key)


def get_enumeration_aws(access_key: Optional[str] = None,
                        secret_key: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnumerationAwsResult:
    """
    ## Example Usage
    ### S

    This is an example of how to lookup a region enumeration data source for AWS cloud account.

    **Region enumeration data source for AWS, by the AWS account access key and secret key:**
    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_enumeration_aws(access_key=var["access_key"],
        secret_key=var["secret_key"])
    ```

    The region enumeration data source for AWS cloud account supports the following arguments:


    :param str access_key: Aws Access key ID.
    :param str secret_key: Aws Secret Access Key.
    """
    __args__ = dict()
    __args__['accessKey'] = access_key
    __args__['secretKey'] = secret_key
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:region/getEnumerationAws:getEnumerationAws', __args__, opts=opts, typ=GetEnumerationAwsResult).value

    return AwaitableGetEnumerationAwsResult(
        access_key=__ret__.access_key,
        id=__ret__.id,
        regions=__ret__.regions,
        secret_key=__ret__.secret_key)


@_utilities.lift_output_func(get_enumeration_aws)
def get_enumeration_aws_output(access_key: Optional[pulumi.Input[str]] = None,
                               secret_key: Optional[pulumi.Input[str]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEnumerationAwsResult]:
    """
    ## Example Usage
    ### S

    This is an example of how to lookup a region enumeration data source for AWS cloud account.

    **Region enumeration data source for AWS, by the AWS account access key and secret key:**
    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_enumeration_aws(access_key=var["access_key"],
        secret_key=var["secret_key"])
    ```

    The region enumeration data source for AWS cloud account supports the following arguments:


    :param str access_key: Aws Access key ID.
    :param str secret_key: Aws Secret Access Key.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .aws import *
from .azure import *
from .gcp import *
from .get_aws import *
from .get_azure import *
from .get_gcp import *
from .get_nsxt import *
from .get_nsxv import *
from .get_v_sphere import *
from .get_vmc import *
from .nsxt import *
from .nsxv import *
from .v_sphere import *
from .vmc import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NetworkArgs', 'Network']

@pulumi.input_type
class NetworkArgs:
    def __init__(__self__, *,
                 project_id: pulumi.Input[str],
                 constraints: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkConstraintArgs']]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 outbound_access: Optional[pulumi.Input[bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkTagArgs']]]] = None):
        """
        The set of arguments for constructing a Network resource.
        :param pulumi.Input[str] project_id: The id of the project this resource belongs to.
        :param pulumi.Input[Sequence[pulumi.Input['NetworkConstraintArgs']]] constraints: List of storage, network and extensibility constraints to be applied when provisioning through this project.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional properties that may be used to extend the base resource.
        :param pulumi.Input[str] deployment_id: Deployment id that is associated with this resource.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[bool] outbound_access: Flag to indicate if the network needs to have outbound access or not. Default is true. This field will be ignored if there is proper input for networkType customProperty.
        :param pulumi.Input[Sequence[pulumi.Input['NetworkTagArgs']]] tags: A set of tag keys and optional values that were set on this resource.
               example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        pulumi.set(__self__, "project_id", project_id)
        if constraints is not None:
            pulumi.set(__self__, "constraints", constraints)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if deployment_id is not None:
            pulumi.set(__self__, "deployment_id", deployment_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if outbound_access is not None:
            pulumi.set(__self__, "outbound_access", outbound_access)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        """
        The id of the project this resource belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def constraints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkConstraintArgs']]]]:
        """
        List of storage, network and extensibility constraints to be applied when provisioning through this project.
        """
        return pulumi.get(self, "constraints")

    @constraints.setter
    def constraints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkConstraintArgs']]]]):
        pulumi.set(self, "constraints", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Additional properties that may be used to extend the base resource.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> Optional[pulumi.Input[str]]:
        """
        Deployment id that is associated with this resource.
        """
        return pulumi.get(self, "deployment_id")

    @deployment_id.setter
    def deployment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deployment_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="outboundAccess")
    def outbound_access(self) -> Optional[pulumi.Input[bool]]:
        """
        Flag to indicate if the network needs to have outbound access or not. Default is true. This field will be ignored if there is proper input for networkType customProperty.
        """
        return pulumi.get(self, "outbound_access")

    @outbound_access.setter
    def outbound_access(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "outbound_access", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkTagArgs']]]]:
        """
        A set of tag keys and optional values that were set on this resource.
        example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _NetworkState:
    def __init__(__self__, *,
                 cidr: Optional[pulumi.Input[str]] = None,
                 constraints: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkConstraintArgs']]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 external_zone_id: Optional[pulumi.Input[str]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 outbound_access: Optional[pulumi.Input[bool]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 self_link: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkTagArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Network resources.
        :param pulumi.Input[str] cidr: IPv4 address range of the network in CIDR format.
        :param pulumi.Input[Sequence[pulumi.Input['NetworkConstraintArgs']]] constraints: List of storage, network and extensibility constraints to be applied when provisioning through this project.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional properties that may be used to extend the base resource.
        :param pulumi.Input[str] deployment_id: Deployment id that is associated with this resource.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] external_id: External entity Id on the provider side.
        :param pulumi.Input[str] external_zone_id: The external zoneId of the resource.
        :param pulumi.Input[Sequence[pulumi.Input['NetworkLinkArgs']]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] organization_id: The id of the organization this entity belongs to.
        :param pulumi.Input[bool] outbound_access: Flag to indicate if the network needs to have outbound access or not. Default is true. This field will be ignored if there is proper input for networkType customProperty.
        :param pulumi.Input[str] owner: Email of the user that owns the entity.
        :param pulumi.Input[str] project_id: The id of the project this resource belongs to.
        :param pulumi.Input[str] self_link: Self link of this request.
        :param pulumi.Input[Sequence[pulumi.Input['NetworkTagArgs']]] tags: A set of tag keys and optional values that were set on this resource.
               example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        if cidr is not None:
            pulumi.set(__self__, "cidr", cidr)
        if constraints is not None:
            pulumi.set(__self__, "constraints", constraints)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if deployment_id is not None:
            pulumi.set(__self__, "deployment_id", deployment_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if external_zone_id is not None:
            pulumi.set(__self__, "external_zone_id", external_zone_id)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if outbound_access is not None:
            pulumi.set(__self__, "outbound_access", outbound_access)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if self_link is not None:
            pulumi.set(__self__, "self_link", self_link)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter
    def cidr(self) -> Optional[pulumi.Input[str]]:
        """
        IPv4 address range of the network in CIDR format.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr", value)

    @property
    @pulumi.getter
    def constraints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkConstraintArgs']]]]:
        """
        List of storage, network and extensibility constraints to be applied when provisioning through this project.
        """
        return pulumi.get(self, "constraints")

    @constraints.setter
    def constraints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkConstraintArgs']]]]):
        pulumi.set(self, "constraints", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Additional properties that may be used to extend the base resource.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> Optional[pulumi.Input[str]]:
        """
        Deployment id that is associated with this resource.
        """
        return pulumi.get(self, "deployment_id")

    @deployment_id.setter
    def deployment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deployment_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter(name="externalZoneId")
    def external_zone_id(self) -> Optional[pulumi.Input[str]]:
        """
        The external zoneId of the resource.
        """
        return pulumi.get(self, "external_zone_id")

    @external_zone_id.setter
    def external_zone_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_zone_id", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkLinkArgs']]]]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter(name="outboundAccess")
    def outbound_access(self) -> Optional[pulumi.Input[bool]]:
        """
        Flag to indicate if the network needs to have outbound access or not. Default is true. This field will be ignored if there is proper input for networkType customProperty.
        """
        return pulumi.get(self, "outbound_access")

    @outbound_access.setter
    def outbound_access(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "outbound_access", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the project this resource belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="selfLink")
    def self_link(self) -> Optional[pulumi.Input[str]]:
        """
        Self link of this request.
        """
        return pulumi.get(self, "self_link")

    @self_link.setter
    def self_link(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "self_link", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkTagArgs']]]]:
        """
        A set of tag keys and optional values that were set on this resource.
        example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class Network(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkConstraintArgs']]]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 outbound_access: Optional[pulumi.Input[bool]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkTagArgs']]]]] = None,
                 __props__=None):
        """
        ## Example Usage
        ### S

        This is an example of how to create a network resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        my_network = vra.network.Network("myNetwork",
            constraints=[vra.network.NetworkConstraintArgs(
                expression="pci",
                mandatory=True,
            )],
            outbound_access=False,
            tags=[vra.network.NetworkTagArgs(
                key="foo",
                value="bar",
            )])
        ```
        A network resource supports the following resource:

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkConstraintArgs']]]] constraints: List of storage, network and extensibility constraints to be applied when provisioning through this project.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional properties that may be used to extend the base resource.
        :param pulumi.Input[str] deployment_id: Deployment id that is associated with this resource.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[bool] outbound_access: Flag to indicate if the network needs to have outbound access or not. Default is true. This field will be ignored if there is proper input for networkType customProperty.
        :param pulumi.Input[str] project_id: The id of the project this resource belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkTagArgs']]]] tags: A set of tag keys and optional values that were set on this resource.
               example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage
        ### S

        This is an example of how to create a network resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        my_network = vra.network.Network("myNetwork",
            constraints=[vra.network.NetworkConstraintArgs(
                expression="pci",
                mandatory=True,
            )],
            outbound_access=False,
            tags=[vra.network.NetworkTagArgs(
                key="foo",
                value="bar",
            )])
        ```
        A network resource supports the following resource:

        :param str resource_name: The name of the resource.
        :param NetworkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkConstraintArgs']]]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 outbound_access: Optional[pulumi.Input[bool]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkTagArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkArgs.__new__(NetworkArgs)

            __props__.__dict__["constraints"] = constraints
            __props__.__dict__["custom_properties"] = custom_properties
            __props__.__dict__["deployment_id"] = deployment_id
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["outbound_access"] = outbound_access
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["cidr"] = None
            __props__.__dict__["external_id"] = None
            __props__.__dict__["external_zone_id"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["self_link"] = None
            __props__.__dict__["updated_at"] = None
        super(Network, __self__).__init__(
            'vra:network/network:Network',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cidr: Optional[pulumi.Input[str]] = None,
            constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkConstraintArgs']]]]] = None,
            custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            deployment_id: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            external_id: Optional[pulumi.Input[str]] = None,
            external_zone_id: Optional[pulumi.Input[str]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            organization_id: Optional[pulumi.Input[str]] = None,
            outbound_access: Optional[pulumi.Input[bool]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            self_link: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkTagArgs']]]]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'Network':
        """
        Get an existing Network resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cidr: IPv4 address range of the network in CIDR format.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkConstraintArgs']]]] constraints: List of storage, network and extensibility constraints to be applied when provisioning through this project.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional properties that may be used to extend the base resource.
        :param pulumi.Input[str] deployment_id: Deployment id that is associated with this resource.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] external_id: External entity Id on the provider side.
        :param pulumi.Input[str] external_zone_id: The external zoneId of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkLinkArgs']]]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] organization_id: The id of the organization this entity belongs to.
        :param pulumi.Input[bool] outbound_access: Flag to indicate if the network needs to have outbound access or not. Default is true. This field will be ignored if there is proper input for networkType customProperty.
        :param pulumi.Input[str] owner: Email of the user that owns the entity.
        :param pulumi.Input[str] project_id: The id of the project this resource belongs to.
        :param pulumi.Input[str] self_link: Self link of this request.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NetworkTagArgs']]]] tags: A set of tag keys and optional values that were set on this resource.
               example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkState.__new__(_NetworkState)

        __props__.__dict__["cidr"] = cidr
        __props__.__dict__["constraints"] = constraints
        __props__.__dict__["custom_properties"] = custom_properties
        __props__.__dict__["deployment_id"] = deployment_id
        __props__.__dict__["description"] = description
        __props__.__dict__["external_id"] = external_id
        __props__.__dict__["external_zone_id"] = external_zone_id
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["outbound_access"] = outbound_access
        __props__.__dict__["owner"] = owner
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["self_link"] = self_link
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        return Network(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def cidr(self) -> pulumi.Output[str]:
        """
        IPv4 address range of the network in CIDR format.
        """
        return pulumi.get(self, "cidr")

    @property
    @pulumi.getter
    def constraints(self) -> pulumi.Output[Optional[Sequence['outputs.NetworkConstraint']]]:
        """
        List of storage, network and extensibility constraints to be applied when provisioning through this project.
        """
        return pulumi.get(self, "constraints")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Additional properties that may be used to extend the base resource.
        """
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> pulumi.Output[str]:
        """
        Deployment id that is associated with this resource.
        """
        return pulumi.get(self, "deployment_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> pulumi.Output[str]:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalZoneId")
    def external_zone_id(self) -> pulumi.Output[str]:
        """
        The external zoneId of the resource.
        """
        return pulumi.get(self, "external_zone_id")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.NetworkLink']]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[str]:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter(name="outboundAccess")
    def outbound_access(self) -> pulumi.Output[Optional[bool]]:
        """
        Flag to indicate if the network needs to have outbound access or not. Default is true. This field will be ignored if there is proper input for networkType customProperty.
        """
        return pulumi.get(self, "outbound_access")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        The id of the project this resource belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="selfLink")
    def self_link(self) -> pulumi.Output[str]:
        """
        Self link of this request.
        """
        return pulumi.get(self, "self_link")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.NetworkTag']]:
        """
        A set of tag keys and optional values that were set on this resource.
        example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        return pulumi.get(self, "updated_at")

